@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2001 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item MAC
Mandatory Access Control (MLS)

@item MAC
Media Access Control (ISO, OSI)

@item MAC
Membership Advisory Committee (ICANN)

@item MAC
Message Authentication Code (SSL, SRT, cryptography)

@item MACH
Multilayer ACtuator Head

@item MACID
Media Access Control IDentifier, "MAC-ID"

@item MACOS
MACintosh Operating System (Apple, OS), "MacOS"

@item MACS
Manufacturing Application Control System (SNI)

@item MACS
Modem Access Control System (MODEM, DES), "M.A.C.S."

@item MACSBUG
Motorola Advanced Computer Symbolic deBUGger (Motorola)

@item MAD
Memory Address Driver strength (BIOS)

@item MAD
Message Address Directory

@item MAD
Militaerischer AbschirmDienst (mil., org.)

@item MADE
Multimedia Application Development Environment (CWI)

@item MADK
Microsoft Activex Development Kit (ActiveX, MS)

@item MAE
Macintosh Application Environment (Apple, Sun, HPUX)

@item MAINSAIL
MAchine INdependent SAIL (SAIL)

@item MAJC
Microprocessor Architecture for Java Computing [pronounced 'magic'] (Sun, Java)

@item MAJOUR
Modular Application for JOURnals (EWS, SGML)

@item MAME
Multiple Arcade Machine Emulator, "M.A.M.E."

@item MAN
Metropolitan Area Network

@item MAP
Maintenance Analysis Procedure (IBM)

@item MAP
Manufacturing Automation Protocol (General Motors)

@item MAP
Mobile Application Part (MSC, GSM, Mobile-Systems)

@item MAP27
Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"

@item MAPASE
Mobile Application Part - Application Service Elements (MAP, MSC, GSM, Mobile-Systems), "MAP-ASE"

@item MAPI
Messaging Application Program Interface (MS, WOSA, API)

@item MAPTOP
Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 

@item MAR
Microprogram Address Register

@item MARC
MAchine Readable Cataloging [record]

@item MAS
Multi Agent Systems (AI)

@item MAS90
Mittelstands-Anwendungs-System 90 (IBM)

@item MASE
Message Administration Service Element

@item MASM
Microsoft ASseMbler (MS, assembler)

@item MAU
Medium Access Unit

@item MAU
Medium Attachment Unit (IEEE 802.3, Transceiver)

@item MAU
Multistation Access Unit (Token Ring, Hub)

@item MAUS
Muensters Apple User Service (BBS, network), "M.A.U.S."

@item MAW
Microsoft At Work

@item MAWI
MAterialWIrtschaft

@item MAX
MAssively parallel uniX (Cray, OS, MIMD, MPP, Unix)

@item MAX
Media Access Exchange (Ascend)

@item MB
MailBox

@item MB
MegaByte

@item MBAG
Mercedes-Benz AktienGesellschaft (Anwender)

@item MBCMS
Mercedes-Benz-Computer-Mikrofilm-System (MBAG), "MB-CMS"

@item MBE
Molecular Beam Epitaxy (IC; MOSFET)

@item MBPS
MegaBits Per Second

@item MBR
Master Boot Record

@item MBS
Maximum Burst Size

@item MBUS
Module BUS [standard] (Sun, SPARC), "MBus"

@item MCA
Micro Channel Architecture (IBM, PS/2)

@item MCA
Mission Critical Applications

@item MCAD
Mechanical CAD (AutoCAD, CAD)

@item MCAV
Modified Constant Angular Velocity

@item MCB
Memory Control Block (DOS, TPA)

@item MCBF
Mean Cycle Between Failure

@item MCC
Manchester Code Converter

@item MCC
Manchester Computing Centre (Linux)

@item MCC
Mitteldeutsches Communication Center (Leipzig)

@item MCD
Mini Client Driver (MS, Windows NT)

@item MCD
Multimedia Cartridge Drive (Nomai)

@item MCEB
Military Communications-Electronics Board (org., mil., USA)

@item MCF
Meta Content Framework / Format (Apple, WWW)

@item MCGA
Multi Color Graphics Adapter (IBM, PS/2)

@item MCH
Memory Controller Hub [aka Northbridge] (Intel)

@item MCI
Measurement Layer Interface (UMA)

@item MCI
Media Control Interface

@item MCI
Microwave Communications Incorporated

@item MCL
Media Communication Lab (org., Uni Boston, USA)

@item MCM
MultiChip Module (CPU)

@item MCN
Metropolitan Campus Network

@item MCNE
Master Certified Netware Engineer (Novell, Netware)

@item MCNS
??? [cable modem standard] (org.)

@item MCP
Master Control Program

@item MCP
Multiport / Multiprotocol Communication Processor

@item MCPAS
Master Control Program/Advanced System, "MCP/AS" 

@item MCPC
Multi Channel Per Carrier

@item MCPS
Microsoft Certified Product Specialist (MS, ATEC)

@item MCR
Minimum Cell Rate (UNI, ATM, PCR, ABR)

@item MCS
Material Control System

@item MCS
Message Conversion System

@item MCS
Modulation and Coding Scheme (EGPRS, Mobile-Systems)

@item MCS
MultiCast Server

@item MCS
Multichannel Communications System (Mac)

@item MCS
Multivender Customer Services (DEC)

@item MCSD
Microsoft Certified Solution Developer (MS, ATEC)

@item MCSE
Microsoft Certified System Engineer (MS, ATEC)

@item MCSMP
Message Conversion System Message Processor (MCS)

@item MCSS
Mitac Computer Security System (Mitac)

@item MCT
Microsoft Certified Trainer (MS, ATEC)

@item MCTD
Mean Cell Transfer Delay (UNI, ATM)

@item MCU
Management & Cascade Unit (Hub)

@item MCU
Micro Controller Unit (SIA, RL)

@item MCU
Multipoint Control Unit

@item MCVA
Modified Constant Angular Velocity (Optical Disk)

@item MD
Make Directory (DOS, OS/2)

@item MD
Management DOMAIN

@item MD
Mini Disk (Sony)

@item MD2
Message Digest [algorithm] 2 (RFC 1115/1319)

@item MD4
Message Digest [algorithm] 4 (RFC 1320)

@item MD5
Message Digest [algorithm] 5 (RFC 1321)

@item MDA
Mail Delivery Agent

@item MDA
Medicated Digest Authentication (HTTP)

@item MDA
Monochrome Display Adapter (IBM, PC)

@item MDBMS
Multidimensional DataBase Management System (DBMS, DB)

@item MDBS
Micro Data Base System (DB)

@item MDC
Message conversion system directory Component (MCS)

@item MDC
Meta Data Coalition

@item MDCT
Modified Discrete Cosine Transformation

@item MDDB
MultiDimensional DataBase (DB)

@item MDE
??? DatenErfassung

@item MDI
Medium Dependent Interface (ethernet)

@item MDI
Mobile Data Initiative (org., GSM, Mobile-Systems)

@item MDI
Multiple Document Interface (MS, Windows)

@item MDI
Multiplex Device Interface

@item MDIS
MetaData Interchange Specification

@item MDK
MODEM Developers Kit (MODEM, MS)

@item MDL
Microstation Development Language (CAD)

@item MDRAM
Multibank Dynamic Random Access Memory (RAM, DRAM, IC)

@item MDRC
Manufacturing Design Rule Checker

@item MDS
Manufacturing Design System

@item MDSE
Message Delivery Service Element

@item MDSP
Mobile Device Sync Protocol (Lotus)

@item MDT
Mechanical DeskTop (SGI)

@item MDT
Message Distribution Terminal

@item MDT
Mittlere DatenTechnik

@item MDT
Mountain Daylight Time [-0600] (TZ, MST, USA)

@item ME
Mapping Entity

@item ME
Millennium Edition (MS, Windows)

@item MEG
Mega Evil Grin (slang, Usenet, IRC)

@item MEGA
MessdatenErfassung und Graphische Auswertung

@item MEI
Matsushita Electronics Incorporated (manufacturer, Japan)

@item MEL
Maya Embedded Language

@item MEMS
Micro-ElectroMechanical System

@item MERS
Most Economic Route Selection

@item MES
Manufacturing Execution System

@item MES
Menue-EntwicklungsSystem (Sinix, SNI)

@item MES
Minimum European Set (UTF, ISO 10646)

@item MESA
MetaEmailSearchAgent (WWW, Internet)

@item MESCH
Multi-WAIS Engine for Searching Commercial Hosts (WAIS, WWW)

@item MESFET
MEtal Semiconductor Field Effect Transistor (IC, FET)

@item MESH
Macintosh Enhanced SCSI Hardware (Apple, SCSI)

@item MESI
Modified - Exclusive - Shared - Invalid (SMP)

@item MESN
Media Event Status Notification

@item MESZ
MittelEuropaeische SommerZeit [+0200] (TZ)

@item MET
Memory Enhancement Technology (HP), "MEt"

@item MET
Middle European Time [+0100] (TZ, CET, METDST, MEZ)

@item METAL
Machine Evaluation and Translation Language (Siemens)

@item METDST
Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)

@item MEZ
MittelEuropaeische [sommer] Zeit [+0200] (TZ)

@item MF
Multi Frequency

@item MFAST
Mwave Folded Array Signal Transform [DSP] (IBM, DSP)

@item MFC
Microsoft Foundation Classes

@item MFC
Music Feature Card (IBM, Yamaha, MIDI)

@item MFENET
Magnetic Fusion Energy NETwork

@item MFG
Mit Freundlichen Gruessen [= best wishes]

@item MFG
Multi-Function Gateway

@item MFI
MainFrame Interactive (IBM)

@item MFII
Multi-Functional [keyboard] II (IBM)

@item MFIP
Multi-Function Interoperability Processor

@item MFKS
MultiFunktionales KonferenzSystem

@item MFLOPS
Million FLoating-point Operations Per Second (CPU)

@item MFM
Modified Frequency Modulation

@item MFP
MultiFunction Product

@item MFS
Macintosh File System (Apple)

@item MFS
Message Format Service (IBM, IMS)

@item MFS
Mobile File Sync (IBM)

@item MFS
MOSIX File System (MOSIX, DFSA)

@item MFT
Master File Table (NTFS)

@item MFV
MehrFrequenzwahlVerfahren

@item MGA
Matrox Graphics Adapter (Matrox)

@item MGA
Monochrome Graphics Adapter

@item MGI
Multi-Function Interpreter

@item MGM
Memory Grant Manager (Informix, DB)

@item MH
Mobile Host (MHP)

@item MH
Modified Huffman (Fax)

@item MHDL
MIMIC Hardware Description Language

@item MHEG
Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)

@item MHP
[columbia] Mobile Host Protocol

@item MHP
Multimedia Home Platform (ETSI)

@item MHPCC
Maui High Performance Computing Center (org., USA)

@item MHS
Message Handling System (GOSIP, X.400, Novell, SPX, IPX)

@item MHTML
Messaging HyperText Markup Language (HTML)

@item MHTML
MIME [e-mail encapsulation of aggregate documents, such as] HTML (MIME, HTML, RFC 2110)

@item MI
Management Interface

@item MIA
Missing In Action (DFUe, Usenet, IRC)

@item MIAW
Movie In A Window

@item MIB
Management Information Base (OSI, SNMP)

@item MIC
Media Interface Connector (FDDI, PMD)

@item MIC
Memory in Cassette (Seagate, EEPROM, Streamer, AIT)

@item MIC
Message Integrity Check / Code

@item MIC
Multiple Interface Connection (Kyocera)

@item MICA
MODEM ISDN Channel Integration (Telebit, MODEM, ISDN)

@item MICE
Modular Integrated Communications Environment

@item MICO
MICO Is CORBA (ORB, CORBA, Uni Frankfurt)

@item MID
Message IDentifier (ATM)

@item MIDI
Musical Instruments Digital Interface (MIDI)

@item MIDL
Microsoft Interface Definition Language (NT)

@item MIF
Module Interconnection Facility (Proteus)

@item MIG
Mach Interface Generator (Mach)

@item MII
Media Independent Interface

@item MIL
Matrox Imaging Library

@item MILNET
MILitary NETwork (USA, mil., network)

@item MILOS
Maschinelle Indizierung auf Linguistischer Grundlage fuer OPAC Systeme (OPAC)

@item MILSTAR
Military Strategic TActical Relay (mil., USA)

@item MILSTD
Military STandarD (mil., USA), "MIL-STD"

@item MIMD
Multiple Instruction [stream], Multiple Data [stream] (CPU)

@item MIME
Multipurpose Internet Mail Extensions (RFC 2045/2046/2047/2048/2049, IETF)

@item MIMOLA
Machine Independent MicrOprogramming LAnguage (HDL)

@item MIN
Multistage Interconnection Networks

@item MINISTREL
Models for INformatIon STorage and REtrievaL (OA, BIS, ESPRIT)

@item MINT
Mint is Not TOS (Atari), "MiNT"

@item MINT
Multimedia-kommunikation aif Integrierten Netzen und Terminals

@item MINX
Multimedia Information Network eXchange

@item MIO
Memory Input/Output (Motorola)

@item MIO
Modular Input/Output [architecture] (HP)

@item MIP
Multimission Interactive Picture

@item MIPS
Microprocessor without Interlocked Piped Stages

@item MIPS
Million Instructions Per Second (CPU)

@item MIR
Maximum Information Rate

@item MIR
Micro-Instruction Register

@item MIS
Management Information System

@item MISD
Multiple Instruction [stream], Single Data [stream] (CPU)

@item MISS
Mecklenburg Internet Service System (ISP)

@item MISSI
Multilevel Information System Security Initiative (org.)

@item MISX
Metered Services Information eXchange (Internet)

@item MIT
Management Information Tree

@item MIT
Massachusetts Institute of Technology (org., USA)

@item MJ
Modular Jack

@item MKS
Mortice Kern Systems (manufacturer)

@item MKT
Multifunktionelles KartenTerminal (CT, ICC)

@item ML
Mail List

@item ML
Meta Language

@item MLA
Mail List Agent

@item MLA
Micro Lens Array

@item MLC
MultiLevel Cell (IC, PCMCIA, Flash, Intel)

@item MLE
MultiLine Entry field (IBM, OS/2)

@item MLI
Measurement Layer Interface (UMA)

@item MLI
Multiple Link Interface (ODI)

@item MLIA
[symposium on] Machine Learning in Information Access (AAAI, AI, conference)

@item MLID
Multiple Link Interface Driver (ODI, LAN)

@item MLM
Mailing List Manager [software]

@item MLMA
Multi-Level Multi-Access (MAC)

@item MLP
MultiLink Point-to-Point Protocol (PPP)

@item MLR
Multi-channel Linear Recording [technology] (Tandberg, Streamer)

@item MLS
MultiLevel Secure [operating systems / platforms]

@item MLT
Master Lower Tester (ISO 9646-3, TTCN)

@item MLT3
MuLTilevel-3 [encoding] (Schneider & Koch, FDDI), "MLT-3"

@item MM
Media Manager (Novell, Netware, SMS)

@item MM
Military Message (mil.)

@item MM
Mobile Management (RR, CM, GSM, Mobile-Systems)

@item MMA
Microcomputer Managers Association (org., USA)

@item MMA
MIDI Manufacturer Association (org., IMA)

@item MMC
Microsoft Management Console (MS, Windows NT)

@item MMC
MIDI Machine Control

@item MMC
MultiMedia Commands (SAM)

@item MMC
MultiMediaCard

@item MMCD
MultiMedia Compact Disk (Sony, Philips, CD)

@item MMCDE
MultiMedia Compact Disk - Erasable (Sony, Philips, CD), "MMCD-E"

@item MMCF
MultiMedia Communications Forum (org.)

@item MMDO
Magnetic Modulation Direct Overwrite

@item MMDS
Multi-channel, Multi-point Distribution System

@item MMF
Make Money Fast (Usenet, ECP, EMP)

@item MMF
Memory Mapped File (Windows 95, Windows NT)

@item MMF
Multimode Fiberoptic cable

@item MMFS
Manufacturing Message Format Standard (MAP)

@item MMHID
MultiMedia Human Interface Device

@item MMHS
Military Message Handling System (mil., MHS)

@item MMI
Mixed Mode Interpreter (JIT, IBM, Java)

@item MMIO
Memory Mapped I/O (I/O)

@item MML
Maker Markup Language (FrameMaker)

@item MMP
Multilink Multichasis PPP (PPP)

@item MMPM2
MultiMedia Presentation Manager /2 (IBM, OS/2), "MMPM/2"

@item MMR
Modified Modified Read (Fax)

@item MMS
Manufacturing Message Specifications / Standard (MAP, EIA, RS-511, ISO, DIS 9506)

@item MMS
Maximum Message Size

@item MMS
Module Making System (VMS)

@item MMS
Multilevel Mail Server

@item MMU
Mass Memory Unit

@item MMU
Memory Management Unit

@item MMVF
MultiMedia Video File [disk] (NEC, DVD)

@item MMWM
MultiMedia Window Manager (X-Windows)

@item MMX
MultiMedia eXtensions (Intel, CPU)

@item MNG
Multiple-image Network Graphics [format]

@item MNOS
Metal Nitride Oxide Semiconductor (IC)

@item MNP
Microcom Networking Protocol

@item MO
Management Object (OSI)

@item MOCS
Microsoft Official Curriculum Seminar (MS, ATEC, MCSD)

@item MOD
Magneto-Optical Disk (OD)

@item MODACOM
MObile DAta COMmunication

@item MODCA
Mixed Object Document Content Architecture (IBM), "MO:DCA"

@item MODEM
MOdulator DEModulator

@item MOE
Measure of Effectiveness

@item MOES
Molekulare Optisch-Elektrische Schaltungstraeger

@item MOESI
Modified - Owner - Exclusive - Shared - Invalid (AMD)

@item MOF
Meta Object Facility

@item MOLAP
Multidimensional OnLine Analytical Processing (OLAP)

@item MOLED
Molecule Organic Light Emitting Display (OLED)

@item MOLI
Microsoft OnLine Institute (MS)

@item MOLP
Microsoft Open Licence Pack (MS)

@item MOM
Message Orientated Middleware (IBM)

@item MONALISA
MOdelling NAturaL Images for Synthesis and Animation, "MONA LISA"

@item MONET
high data rate MObile interNET (network)

@item MOO
MUD Object Orientated (Internet, OOP, MUD)

@item MOP
Maintenance Operations Protocol (DEC)

@item MOP
Meta Object Protocol (CLOS)

@item MOP
Multiple Original Prints

@item MOPS
Million Operations Per Second

@item MOS
Metal Oxide Semiconductor (IC)

@item MOSES
Major Open Systems Environment Standards

@item MOSFET
Metal Oxide Semiconductor Field Effect Transistor (IC, FET)

@item MOSIX
Multiprocessor ??? Operating System for unIX (Unix, Cluster)

@item MOSP
Microsoft Online Services Partnership (MSN)

@item MOSPF
Multicast [extensions to ] Open Shortest Path First [routing] (IP, OSPF, RFC 1584)

@item MOST
Media Orientated Systems Transport

@item MOST
Mobile Open Systems Technologies (UK, Uni Lancaster)

@item MOT
Means of Test

@item MOTIS
Message-Orientated Text Interchange System (ISO 10021, JTC1)

@item MOTSS
More Of The Sameold Sameold (Usenet)

@item MOU
Memorandum Of Understanding (IPOC, TLD, Internet)

@item MOVE
Microsoft Overlay Virtual Environment (MS)

@item MOVI
[projekt] MObile VIsualisierung (DFG)

@item MOWORM
Magneto-Optical Write Once Read Many, "MO-WORM" 

@item MP
[PPP] Multilink Protocol (MPPP, RFC 1990)

@item MP
Multi Processor

@item MP
MultiProtocol

@item MP3
MPEG audio layer 3 (MPEG, audio, IIS, ISO)

@item MPC
MPOA Client (MPOA, ATM)

@item MPC
Multimedia Personal Computer

@item MPD
Message Preparation Directory

@item MPDA
MultiPlatform DiskArray

@item MPDU
Message Protocol Data Unit (PDU)

@item MPEG
Motion Picture Expert Group [old term] (MPEG)

@item MPEG
Moving Picture Expert Group (org., ISO 11172-1, JTC1)

@item MPEXL
??? (HP), "MPE/XL"

@item MPI
Message Passing Interface (SMP, Cluster)

@item MPI
Multiprocessor Interconnect Bus

@item MPIF
Message Passing Interface Forum (manufacturer)

@item MPL
Mozilla Public License (Netscape)

@item MPM
Metra Potential Method

@item MPM2
MultiMedia Presentation Manager/2 (OS/2, IBM), "MPM/2"

@item MPML
Main Profile @@ Main Level (MPEG), "MP@@ML"

@item MPOA
Multi-Protocol Over ATM (ATM)

@item MPOW
Multiple Purpose Operator Workstation

@item MPP
Massive Parallel Processor / Processing (MPP)

@item MPP
Message Posting Protocol (RFC 1204)

@item MPP
Message Processing Program

@item MPPC
Microsoft Point-to-Point Compression (MS, RFC 2118)

@item MPPD
Multi Purpose Peripheral Device

@item MPPE
Microsoft Point to Point Encryption (MS, cryptography)

@item MPPP
Multilink Point-to-Point Protocol (PPP, RFC 1990, MP, Ascend)

@item MPR
[National Board for Metrology and Testing] (org., Sweden)

@item MPS
Megabytes Per Second

@item MPS
MPOA Server (MPOA, ATM)

@item MPS
MultiPage Signal (Fax)

@item MPS
MultiProzessor Spezifikation (SMP)

@item MPSX
Mathematical Programming System eXtended (IBM)

@item MPT
Ministery of Post and Telecommunications (org., Japan)

@item MPT
MultiPort Transceiver

@item MPT1327
???

@item MPTA
Multi Protocol Transport Architecture (IBM, SNA)

@item MPTN
Multi Protocol Transport Networking (IBM)

@item MPTS
Multi Protocol Transport Services (IBM, MPTN)

@item MPTS2
Multi Protocol Transport Services / 2 (IBM, OS/2), "MPTN/2" 

@item MPU
MicroProcessor Unit (SIA, RL)

@item MPU401
MIDI Processing Unit 401 (Roland, MIDI), "MPU 401"

@item MPW
Macintosh Programmers Workshop (Apple)

@item MQI
Message Queueing Interface (IBM)

@item MQUIPS
Million QUality Improvements Per Second

@item MR
Magneto - Resistive (HDD)

@item MR
MODEM Ready (MODEM)

@item MR
Modified Read (Fax)

@item MRA
Multi Resolutions Analysis

@item MRB
Method Request Broker (OMG)

@item MRBC
Multiple Resolution Bitmap Compiler (MS, Windows)

@item MRCF
Microsoft Realtime Compression Format (MS)

@item MRCI
Microsoft Realtime Compression Interface (MS)

@item MRCS
Multi-Rate Circuit Switching

@item MRH
Memory Repeater Hub (Intel)

@item MRJ
Macintosh / MacOS Runtime for Java (Java, Apple)

@item MRJSDK
Macintosh Runtime for Java Software Developer Kit (Apple, Java), "MRJ SDK"

@item MRM
Multi Resolution Meshes (Intel, 3D)

@item MRNET
Minnesota Regional NETwork (network, USA)

@item MRO
Mandatory Router Option [flag] (CATNIP)

@item MROC
Multicommand Required Operational Capability

@item MROM
??? Read Only Memory (ROM)

@item MRP
Material / Manufacturing Resource Palnning

@item MRP
Material Requirement Planning (PPS, CIM)

@item MRS
Media Recognition System (DAT)

@item MRSE
Message Retrieval Service Element

@item MRTG
Multi Router Traffic Grapher

@item MRU
Maximum Receive Unit [size] (SLIP, PPP)

@item MRU
Most Recently Used

@item MRX
MagnetoResistive eXtended [technology] (HDD)

@item MS
Message Store

@item MS
Meta Signaling (ATM, ???)

@item MS
MicroSoft (manufacturer, MS)

@item MS
Mobile Station (GSM, Mobile-Systems)

@item MSA
Management Service Architecture

@item MSAP
Management Service Access Point (OSI, OSI/RM, SAP)

@item MSAP
Mini Slotted Alternating Priorities (MAC)

@item MSB
Most Significant Bit

@item MSC
MicroSoft C

@item MSC
Mobile services Switching Center (PLMN, GSM, GPRS, Mobile-Systems)

@item MSCDEX
MicroSoft Compact Disk EXtensions (CD)

@item MSCHAP
MicroSoft Challenge Handshake Authentication Protocol (MS), "MS-CHAP"

@item MSCM
Multiple Slots on Continuation Mechanism (DQDB)

@item MSCP
Mass Storage Control Protocol

@item MSCS
MicroSoft Cluster Server [Wolfpack] (MS, Cluster)

@item MSD
Most Significant Digit

@item MSDE
MicroSoft Data Engine (MS, DB)

@item MSDL
MicroSoft Download Library (MS)

@item MSDN
Macintosh Software Distribution Network (FidoNet, Apple)

@item MSDN
MicroSoft Developer Network (Internet, MS)

@item MSDN
MicroSoft Developer Network (MS)

@item MSDOS
MicroSoft Disk Operating System (MS, OS)

@item MSE
MicroSoft Exchange server (MS)

@item MSEN
Media Status Event Notification

@item MSFIS
MicroSoft Fax Information Service (MS)

@item MSFP
Management Service Focal Point (IBM)

@item MSI
Medium Scale Integration

@item MSI
Micro-Star International (manufacturer, Taiwan)

@item MSIE
MicroSoft Internet Explorer (MS, WWW, MSIE)

@item MSISDN
Mobile Station ISDN Number (PLMN, GSM, Mobile-Systems), "MS-ISDN"

@item MSIX
Metered Services Information eXchange [protocol] (Internet, ISP)

@item MSL
Maximum Segment Lifetime (TCP/IP)

@item MSL
Microsoft Software Library (Internet, MS)

@item MSL
Mirrored Server Link

@item MSM
Media Support Module (ODI)

@item MSM
Metal Semiconductor Metal (IC)

@item MSMQ
MicroSoft Message Queue [server] (MS)

@item MSN
Microsoft Support Network (Internet, MS)

@item MSN
Monitoring cell Sequence Number (UNI, ATM)

@item MSN
Multiple Subscriber Number (Euro-, ISDN)

@item MSNF
Multiple Systems Networking Facility (IBM)

@item MSP
Media Signal Processor (Samsung, MMX, ARM)

@item MSP
Message Security Protocol

@item MSP
Message Send Protocol (RFC 1159)

@item MSPI
M&T Software Partner International [gmbh]

@item MSR
Machine Specific Register

@item MSR
Mess-, Steuer- und Regelungssysteme

@item MSR
Mobile Support Router (MHP)

@item MSR
Model Specific Registers (Intel, Pentium)

@item MSRN
Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, Mobile-Systems)

@item MSRPC
MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"

@item MSS
MIMOLA Software System (MIMOLA)

@item MSSE
Message Submission Service Element

@item MST
Mountain Standard Time [-0700] (TZ, MDT, USA)

@item MSVC
Meta-Signaling Virtual Channel (ATM)

@item MSVC
MicroSoft Visual C++ (MS)

@item MSW
Machine Status Word

@item MT
Machine [assisted] Translation

@item MT
Mannesmann Tally [gmbh] (manufacturer)

@item MT
Message Transfer / Type

@item MT
Mobile Termination (GSM, Mobile-Systems)

@item MT
Moluccas Time [+0830] (TZ)

@item MTA
Mail Transport Agent (SMTP)

@item MTA
Message Transfer Agent (MTS, OSI, X.400)

@item MTBF
Mean Time Between Failure

@item MTBRP
Mean-Time-Between-Parts-Replacement

@item MTC
Master Test Component (ISO 9646-3, TTCN)

@item MTC
MIDI Time Code (MIDI)

@item MTD
Memory Technology Drivers

@item MTDA
Mean Time Data Availability

@item MTE
MuTating Engine (Viren), "MtE"

@item MTEC
Motorola Training and Education Center (org., Chicago)

@item MTF
Message Text Formats

@item MTF
Microsoft Tape Format (MS)

@item MTF
Modulation Transfer Function

@item MTH
Memory Translator Hub (Intel)

@item MTI
MIPS Technologies Inc. (manufacturer, SGI)

@item MTP
Message Transfer Part (ISDN, GSM, Mobile-Systems)

@item MTRR
Memory Type Range Register (CPU, Pentium Pro)

@item MTS
Message Transfer System (MHS)

@item MTS
Microsoft Transaction Server (MS, DB, WSH, COM)

@item MTTF
Mean Time To Failure

@item MTTFF
Mean Time To First Failure

@item MTTR
Mean Time to Recovery / Repair / React

@item MTTR
Mean Time Trouble Repair

@item MTU
Maximum Transmission Unit (SLIP, PPP, IP)

@item MTU
Message Transfer Unit

@item MUA
Mail User Agent

@item MUBIS
MUltimediales BueroInformationsSystem (OA, BIS, TU Braunschweig), "MuBIS"c

@item MUCK
Multi-User Chat Kingdom (MUD)

@item MUD
Multi-User Dungeon (MUD)

@item MUGD
MUMPS User Group Deutschland (MUMPS, user group), "MUG-D"

@item MUI
Management User Interface (OMF, UI)

@item MUI
Multimedia User Interface (SGI, UI)

@item MULDEM
MULtiplexer-DEMultiplexer

@item MULE
MULtilingual Enhancement of GNU EMACS (EMACS, GNU)

@item MULTICS
MULTiplexed Information and Computing Service (OS)

@item MULTOS
MULtimedia Office Server (OA, BIS, ESPRIT)

@item MUMPS
Massachusetts general hospital Multi-Programming System

@item MUPAD
Multi Processing Algebra Data [tool] (Uni Paderborn, Germany, CAS), "MuPAD"

@item MUSH
Multi-User Shared Hallucination (MUD)

@item MUSICAM
Masking-pattern adapted Universal Subband Integrated Coding And Multiplexing (MPEG, digital audio)

@item MUT
Master Upper Tester (ISO 9646-3, TTCN)

@item MUTOS
MultiUser-/multitasking Operating System (GDR, OS)

MUeW          eW MonopolUebertragungsWeg, "MueW"

@item MUX
MUltipleXer

@item MVA
Multi Vendor Architecture

@item MVA
Multidomain Vertical Alignment [technology] (LCD, Fujitsu)

@item MVC
Model View Controller (Smalltalk, GUI)

@item MVI
Motion Video Instructions (DEC, CPU, Alpha)

@item MVIF
Multi-Vendor Interacting Forum (org., IN)

@item MVP
Most Valuable Professional [bonus program] (MS)

@item MVRCA
Magnalink Variable Resource Compression Algorithm (PPP, RFC 1975)

@item MVS
Multiple Virtual Storage (IBM, OS)

@item MVS
Multiple Virtual System (OS)

@item MVSESA
Multiple Virtual Storage/Extended System Architecture (IBM), "MVS/ESA"

@item MVSESASP
Multiple Virtual Storage/Extended System Architecture System Product (IBM), "MVS/ESA SP"

@item MVSSP
Multiple Virtual Storage/System Product, "MVS/SP" 

@item MVSTSO
Multiple Virtual Storage/Time Sharing Option (IBM), "MVS/TSO"

@item MVSXA
Multiple Virtual Storage/eXtended Architecture, "MVS/XA" 

@item MWS
Management WorkStation

@item MWS
Matsushita White Skipping (Fax)

@item MX
Mail eXchange (Unix)

@item MXB
Multimedia eXension Board (SNI)

@item MXC
Multimedia eXtension Connector

@item MZ
Mark Zbikowski (MS-DOS, MCB)

@end table


